package
Version:
v0.0.0-...-ac4b63c
Opens a new window with list of versions in this module.
Published: Nov 21, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type RequestGeneralTrans struct {
Query string `form:"q" json:"q"`
From string `form:"from" json:"from"`
To string `form:"to" json:"to"`
AppId string `form:"appid" json:"appid"`
Action string `form:"action,omitempty" json:"action,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.